/* This is a GENERATED file. */
void test_version(void);
void test_str_memmem(void);
void test_str_next_line(void);
void test_str_isident_ascii(void);
void test_str_among(void);
void test_str_kill(void);
void test_str_case_equal_ascii(void);
void test_str_case_hash_ascii(void);
void test_str_gstring_replace_null_old(void);
void test_str_gstring_replace_null_replacement(void);
void test_str_gstring_replace_general(void);
void test_str_assign_string(void);
void test_str_assign_gstring(void);
void test_str_utf8_strescape(void);
void test_math_powi_one(void);
void test_math_powi_zero(void);
void test_math_powi_basic(void);
void test_math_deg2rad(void);
void test_math_rad2deg(void);
void test_math_mean(void);
void test_math_sort_double(void);
void test_math_trimmed_mean(void);
void test_math_curvature_apex_straight(void);
void test_math_curvature_apex_parabolic(void);
void test_math_curvature_apex_askew(void);
void test_math_is_in_polygon_square(void);
void test_math_is_in_polygon_bowtie(void);
void test_math_refine_maximum_1d(void);
void test_math_refine_maximum_2d(void);
void test_math_accumulate_counts(void);
void test_error_list_basic(void);
void test_error_list_propagation(void);
void test_raw_data_size_consistency(void);
void test_raw_data_uint8_le_stride1(void);
void test_raw_data_uint8_be_stride1(void);
void test_raw_data_sint8_le_stride1(void);
void test_raw_data_sint8_be_stride1(void);
void test_raw_data_uint8_stride2(void);
void test_raw_data_uint8_stridem1(void);
void test_raw_data_uint8_stride0(void);
void test_raw_data_uint4_be_stride1(void);
void test_raw_data_uint4_be_stride2(void);
void test_raw_data_uint4_be_stride3(void);
void test_raw_data_uint4_be_stridem1(void);
void test_raw_data_uint4_be_stridem2(void);
void test_raw_data_uint4_be_stride0(void);
void test_raw_data_sint4_be_stride1(void);
void test_raw_data_sint4_be_stride2(void);
void test_raw_data_sint4_be_stride3(void);
void test_raw_data_sint4_be_stridem1(void);
void test_raw_data_sint4_be_stridem2(void);
void test_raw_data_uint4_le_stride1(void);
void test_raw_data_uint4_le_stride2(void);
void test_raw_data_uint4_le_stride3(void);
void test_raw_data_uint4_le_stridem1(void);
void test_raw_data_uint4_le_stridem2(void);
void test_raw_data_uint4_le_stride0(void);
void test_raw_data_sint4_le_stride1(void);
void test_raw_data_sint4_le_stride2(void);
void test_raw_data_sint4_le_stride3(void);
void test_raw_data_sint4_le_stridem1(void);
void test_raw_data_sint4_le_stridem2(void);
void test_raw_data_bit_be_stride1(void);
void test_raw_data_bit_be_stride2(void);
void test_raw_data_bit_be_stridem1(void);
void test_raw_data_bit_le_stride1(void);
void test_raw_data_bit_le_stride2(void);
void test_raw_data_bit_le_stridem1(void);
void test_raw_data_bit_stride0(void);
void test_raw_data_uint12_be_stride1(void);
void test_raw_data_uint12_be_stride2(void);
void test_raw_data_uint12_be_stride3(void);
void test_raw_data_uint12_be_stridem1(void);
void test_raw_data_uint12_be_stridem2(void);
void test_raw_data_uint12_be_stride0(void);
void test_raw_data_sint12_be_stride1(void);
void test_raw_data_sint12_be_stride2(void);
void test_raw_data_sint12_be_stride3(void);
void test_raw_data_sint12_be_stridem1(void);
void test_raw_data_sint12_be_stridem2(void);
void test_raw_data_uint16_be_stride1(void);
void test_raw_data_uint16_be_stride2(void);
void test_raw_data_uint16_be_stridem1(void);
void test_raw_data_uint16_be_stride0(void);
void test_raw_data_uint16_le_stride1(void);
void test_raw_data_uint16_le_stride2(void);
void test_raw_data_uint16_le_stridem1(void);
void test_raw_data_uint16_le_stride0(void);
void test_raw_data_sint16_be_stride1(void);
void test_raw_data_sint16_be_stride2(void);
void test_raw_data_sint16_be_stridem1(void);
void test_raw_data_sint16_le_stride1(void);
void test_raw_data_sint16_le_stride2(void);
void test_raw_data_sint16_le_stridem1(void);
void test_raw_data_uint24_be_stride1(void);
void test_raw_data_uint24_be_stride2(void);
void test_raw_data_uint24_be_stridem1(void);
void test_raw_data_uint24_be_stride0(void);
void test_raw_data_uint24_le_stride1(void);
void test_raw_data_uint24_le_stride2(void);
void test_raw_data_uint24_le_stridem1(void);
void test_raw_data_uint24_le_stride0(void);
void test_raw_data_sint24_be_stride1(void);
void test_raw_data_sint24_be_stride2(void);
void test_raw_data_sint24_be_stridem1(void);
void test_raw_data_sint24_le_stride1(void);
void test_raw_data_sint24_le_stride2(void);
void test_raw_data_sint24_le_stridem1(void);
void test_raw_data_uint32_be_stride1(void);
void test_raw_data_uint32_be_stride2(void);
void test_raw_data_uint32_be_stridem1(void);
void test_raw_data_uint32_be_stride0(void);
void test_raw_data_uint32_le_stride1(void);
void test_raw_data_uint32_le_stride2(void);
void test_raw_data_uint32_le_stridem1(void);
void test_raw_data_uint32_le_stride0(void);
void test_raw_data_sint32_be_stride1(void);
void test_raw_data_sint32_be_stride2(void);
void test_raw_data_sint32_be_stridem1(void);
void test_raw_data_sint32_le_stride1(void);
void test_raw_data_sint32_le_stride2(void);
void test_raw_data_sint32_le_stridem1(void);
void test_raw_data_uint64_be_stride1(void);
void test_raw_data_uint64_be_stride2(void);
void test_raw_data_uint64_be_stridem1(void);
void test_raw_data_uint64_be_stride0(void);
void test_raw_data_uint64_le_stride1(void);
void test_raw_data_uint64_le_stride2(void);
void test_raw_data_uint64_le_stridem1(void);
void test_raw_data_uint64_le_stride0(void);
void test_raw_data_sint64_be_stride1(void);
void test_raw_data_sint64_be_stride2(void);
void test_raw_data_sint64_be_stridem1(void);
void test_raw_data_sint64_le_stride1(void);
void test_raw_data_sint64_le_stride2(void);
void test_raw_data_sint64_le_stridem1(void);
void test_raw_data_half_be_stride1(void);
void test_raw_data_half_be_stride2(void);
void test_raw_data_half_be_stridem1(void);
void test_raw_data_half_be_stride0(void);
void test_raw_data_half_le_stride1(void);
void test_raw_data_half_le_stride2(void);
void test_raw_data_half_le_stridem1(void);
void test_raw_data_half_le_stride0(void);
void test_raw_data_pascal_be_stride1(void);
void test_raw_data_pascal_be_stride2(void);
void test_raw_data_pascal_be_stridem1(void);
void test_raw_data_pascal_be_stride0(void);
void test_raw_data_pascal_le_stride1(void);
void test_raw_data_pascal_le_stride2(void);
void test_raw_data_pascal_le_stridem1(void);
void test_raw_data_pascal_le_stride0(void);
void test_raw_data_extended_be_stride1(void);
void test_raw_data_extended_be_stride2(void);
void test_raw_data_extended_be_stridem1(void);
void test_raw_data_extended_be_stride0(void);
void test_raw_data_extended_le_stride1(void);
void test_raw_data_extended_le_stride2(void);
void test_raw_data_extended_le_stridem1(void);
void test_serialization_append_int16(void);
void test_serialization_append_int32(void);
void test_serialization_append_int64(void);
void test_serialization_append_float(void);
void test_serialization_append_double(void);
void test_serialization_append_string(void);
void test_serialization_append_unit(void);
void test_serialization_append_rgba(void);
void test_serialization_append_int8_array(void);
void test_serialization_append_int16_array(void);
void test_serialization_append_int32_array(void);
void test_serialization_append_int64_array(void);
void test_serialization_append_float_array(void);
void test_serialization_append_double_array(void);
void test_serialization_append_string_array(void);
void test_serialization_group_grow_one(void);
void test_serialization_group_grow_many(void);
void test_serialization_fill_pspec(void);
void test_serialization_filter_items_normal(void);
void test_serialization_filter_items_repeating(void);
void test_serialization_filter_items_bad_type(void);
void test_serialization_filter_items_pspec_good(void);
void test_serialization_filter_items_pspec_bad(void);
void test_serialization_check_dimensions_0d(void);
void test_serialization_check_dimensions_1d(void);
void test_serialization_check_dimensions_2d(void);
void test_serialization_check_dimensions_3d(void);
void test_serialization_double_component_normal(void);
void test_serialization_double_component_infnan(void);
void test_serialization_int32_component(void);
void test_serialization_enum_component(void);
void test_serialization_object_component_null(void);
void test_serialization_object_component_single(void);
void test_serialization_object_component_array(void);
void test_serialization_trivial_native(void);
void test_serialization_trivial_32bit(void);
void test_serialization_trivial_64bit(void);
void test_serialization_less_trivial_native(void);
void test_serialization_less_trivial_32bit(void);
void test_serialization_less_trivial_64bit(void);
void test_serialization_nested_native(void);
void test_serialization_nested_32bit(void);
void test_serialization_nested_64bit(void);
void test_serialization_extra_item(void);
void test_serialization_write_error(void);
void test_serialization_fuzz_native(void);
void test_serialization_fuzz_32bit(void);
void test_serialization_fuzz_64bit(void);
void test_string_list_append(void);
void test_string_list_assign(void);
void test_string_list_copy(void);
void test_string_list_serialize_simple(void);
void test_unit_parse_power(void);
void test_unit_parse_power10(void);
void test_unit_parse_meter(void);
void test_unit_parse_micro(void);
void test_unit_parse_combine(void);
void test_unit_parse_confusing_like_prefix(void);
void test_unit_parse_confusing_with_prefix(void);
void test_unit_word_names_simple(void);
void test_unit_word_names_unknown(void);
void test_unit_word_names_prefixed(void);
void test_unit_arithmetic_simple(void);
void test_unit_arithmetic_commutativity(void);
void test_unit_arithmetic_nth_root(void);
void test_unit_serialize_simple(void);
void test_unit_serialize_random(void);
void test_unit_assign(void);
void test_unit_copy(void);
void test_unit_garbage(void);
void test_dict_in_construction(void);
void test_dict_data_boolean(void);
void test_dict_data_int32(void);
void test_dict_data_int64(void);
void test_dict_data_double(void);
void test_dict_data_string(void);
void test_dict_gvalue(void);
void test_dict_notify_boolean(void);
void test_dict_notify_int32(void);
void test_dict_notify_string(void);
void test_dict_notify_object(void);
void test_dict_notify_boxed(void);
void test_dict_prefix(void);
void test_dict_transfer_object_default(void);
void test_dict_transfer_object_force(void);
void test_dict_transfer_object_deep(void);
void test_dict_refcount(void);
void test_dict_keys(void);
void test_dict_copy(void);
void test_dict_assign(void);
void test_dict_serialize_simple(void);
void test_dict_serialize_nested(void);
void test_dict_serialize_text(void);
void test_xy_boxed_serialization(void);
void test_xy_boxed_equal(void);
void test_xy_boxed_assign(void);
void test_xyz_boxed_serialization(void);
void test_xyz_boxed_equal(void);
void test_xyz_boxed_assign(void);
void test_rgba_boxed_serialization(void);
void test_rgba_boxed_equal(void);
void test_rgba_boxed_assign(void);
void test_rgba_interpolation(void);
void test_rgba_pixbuf_pixel_to(void);
void test_rgba_pixbuf_pixel_from(void);
void test_inventory_data_name(void);
void test_inventory_data_nth(void);
void test_inventory_default(void);
void test_inventory_sorting(void);
void test_inventory_functional(void);
void test_resource_default(void);
void test_resource_create_new(void);
void test_resource_dump_parse(void);
void test_gradient_edit(void);
void test_gradient_inventory(void);
void test_gradient_serialization(void);
void test_gradient_copy(void);
void test_gradient_assign(void);
void test_gradient_get_color(void);
void test_gradient_sample(void);
void test_gl_material_edit(void);
void test_gl_material_serialization(void);
void test_gl_material_copy(void);
void test_gl_material_assign(void);
void test_line_basic(void);
void test_line_data_changed(void);
void test_line_serialization(void);
void test_line_copy(void);
void test_line_assign(void);
void test_line_resize(void);
void test_line_part_extract(void);
void test_line_crop(void);
void test_line_part_copy(void);
void test_line_flip(void);
void test_line_clear_part(void);
void test_line_fill_part(void);
void test_line_compatibility_res(void);
void test_line_compatibility_real(void);
void test_line_compatibility_lateral(void);
void test_line_compatibility_value(void);
void test_line_compatibility_measure(void);
void test_line_compatibility_mixed(void);
void test_line_extend_border(void);
void test_line_extend_mirror(void);
void test_line_extend_periodic(void);
void test_line_extend_fixed(void);
void test_line_extend_laplace(void);
void test_line_extend_connect(void);
void test_line_extend_undefined(void);
void test_line_cumulate_plain(void);
void test_line_cumulate_to_cdist(void);
void test_line_line_level(void);
void test_line_fit_line_random(void);
void test_line_fit_line_degenerate(void);
void test_line_stats_avg_linear(void);
void test_line_stats_sum_linear(void);
void test_line_stats_min_linear(void);
void test_line_stats_max_linear(void);
void test_line_stats_rms_linear(void);
void test_line_stats_skew_linear(void);
void test_line_stats_kurtosis_linear(void);
void test_line_stats_variation_linear(void);
void test_line_stats_tan_beta0_linear(void);
void test_line_stats_length_linear(void);
void test_line_peaks_count_peaks(void);
void test_line_peaks_count_valleys(void);
void test_line_peaks_kth_peaks_basic(void);
void test_line_peaks_kth_peaks_average(void);
void test_line_peaks_kth_peaks_too_few(void);
void test_line_peaks_kth_peaks_none(void);
void test_line_peaks_kth_valleys_basic(void);
void test_line_peaks_kth_valleys_average(void);
void test_line_peaks_kth_valleys_too_few(void);
void test_line_peaks_kth_valleys_none(void);
void test_line_laplace_solve(void);
void test_field_basic(void);
void test_field_invalidate(void);
void test_field_data_changed(void);
void test_field_serialization(void);
void test_field_copy(void);
void test_field_assign(void);
void test_field_setval(void);
void test_field_compatibility_res(void);
void test_field_compatibility_real(void);
void test_field_compatibility_lateral(void);
void test_field_compatibility_value(void);
void test_field_compatibility_measure(void);
void test_field_compatibility_mixed(void);
void test_field_resize(void);
void test_field_area_extract(void);
void test_field_crop(void);
void test_field_area_copy(void);
void test_field_flip_x(void);
void test_field_flip_y(void);
void test_field_flip_xy(void);
void test_field_transpose_major(void);
void test_field_transpose_minor(void);
void test_field_clear_area(void);
void test_field_fill_area(void);
void test_field_fill_area_mask(void);
void test_field_fill_mask_01(void);
void test_field_extend_border(void);
void test_field_extend_mirror(void);
void test_field_extend_periodic(void);
void test_field_extend_fixed(void);
void test_field_extend_laplace(void);
void test_field_extend_connect(void);
void test_field_extend_undefined(void);
void test_field_plane_level(void);
void test_field_fit_plane_random(void);
void test_field_fit_plane_degenerate(void);
void test_field_fit_plane_area_basic(void);
void test_field_fit_plane_area_degenerate_2x2(void);
void test_field_fit_poly_linear(void);
void test_field_fit_poly_masked(void);
void test_field_stats_avg_planar(void);
void test_field_stats_avg_bilinear(void);
void test_field_stats_avg_area(void);
void test_field_stats_avg_masked(void);
void test_field_stats_median_full(void);
void test_field_stats_median_area(void);
void test_field_stats_median_masked(void);
void test_field_stats_min_planar(void);
void test_field_stats_min_area(void);
void test_field_stats_min_masked(void);
void test_field_stats_max_planar(void);
void test_field_stats_max_area(void);
void test_field_stats_max_masked(void);
void test_field_stats_min_max_area(void);
void test_field_stats_min_max_masked(void);
void test_field_stats_sum_planar(void);
void test_field_stats_sum_bilinear(void);
void test_field_stats_sum_area(void);
void test_field_stats_sum_masked(void);
void test_field_stats_mean_square_planar(void);
void test_field_stats_mean_square_bilinear(void);
void test_field_stats_mean_square_area(void);
void test_field_stats_mean_square_masked(void);
void test_field_stats_rms_planar(void);
void test_field_stats_rms_bilinear(void);
void test_field_stats_rms_area(void);
void test_field_stats_rms_masked(void);
void test_field_stats_stats_planar(void);
void test_field_stats_stats_bilinear(void);
void test_field_stats_stats_area(void);
void test_field_stats_area_square(void);
void test_field_stats_area_nonsquare(void);
void test_field_stats_variation_square(void);
void test_field_stats_variation_nonsquare(void);
void test_field_stats_volume_constant(void);
void test_field_stats_volume_planar(void);
void test_field_stats_height_dist_full(void);
void test_field_stats_height_dist_area(void);
void test_field_stats_height_dist_masked(void);
void test_field_stats_minkowski_black_auto(void);
void test_field_stats_minkowski_white_auto(void);
void test_field_stats_minkowski_connectivity_auto(void);
void test_field_line_stats_rows_mean(void);
void test_field_line_stats_columns_mean(void);
void test_field_filter_square_minimum(void);
void test_field_filter_square_maximum(void);
void test_field_filter_minmax_minimum(void);
void test_field_filter_minmax_maximum(void);
void test_field_filter_minmax_range(void);
void test_field_filter_minmax_normalization(void);
void test_field_filter_minmax_dilation(void);
void test_field_filter_minmax_frosion(void);
void test_field_filter_rank(void);
void test_field_filter_trimmed_mean(void);
void test_field_local_maximum_subpixel(void);
void test_field_local_maximum_search(void);
void test_field_local_maximum_edge(void);
void test_field_local_maximum_stripe(void);
void test_field_laplace_solve_scattered(void);
void test_field_laplace_solve_numbered(void);
void test_field_laplace_solve_masked(void);
void test_field_laplace_solve_unmasked(void);
void test_field_laplace_solve_all_grains(void);
void test_field_tip_dilation(void);
void test_field_tip_erosion_spike(void);
void test_field_tip_blind_estimate(void);
void test_nield_basic(void);
void test_nield_data_changed(void);
void test_nield_serialization(void);
void test_nield_copy(void);
void test_nield_assign(void);
void test_nield_resize(void);
void test_nield_area_extract(void);
void test_nield_crop(void);
void test_nield_area_copy(void);
void test_nield_flip_x(void);
void test_nield_flip_y(void);
void test_nield_flip_xy(void);
void test_nield_transpose_major(void);
void test_nield_transpose_minor(void);
void test_nield_grain_number_contiguous_simple(void);
void test_nield_grain_number_contiguous_spiral(void);
void test_nield_grain_number_contiguous_negative(void);
void test_nield_grain_clear_at(void);
void test_nield_grain_isolate_reconstruction(void);
void test_nield_grain_isolate_bbox(void);
void test_nield_grain_isolate_at_reconstruction(void);
void test_nield_grain_isolate_at_bbox(void);
void test_nield_compatibility_res(void);
void test_nield_count_full(void);
void test_nield_count_area(void);
void test_nield_count_masked(void);
void test_nield_distance_transform_conn4_merged_noborder(void);
void test_nield_distance_transform_conn4_merged_border(void);
void test_nield_distance_transform_conn8_merged_noborder(void);
void test_nield_distance_transform_conn8_merged_border(void);
void test_nield_distance_transform_octagonal48_merged_noborder(void);
void test_nield_distance_transform_octagonal48_merged_border(void);
void test_nield_distance_transform_octagonal84_merged_noborder(void);
void test_nield_distance_transform_octagonal84_merged_border(void);
void test_nield_distance_transform_octagonal_merged_noborder(void);
void test_nield_distance_transform_octagonal_merged_border(void);
void test_nield_distance_transform_euclidean_merged_noborder(void);
void test_nield_distance_transform_euclidean_merged_border(void);
void test_nield_distance_transform_conn4_split_noborder(void);
void test_nield_distance_transform_conn4_split_border(void);
void test_nield_distance_transform_conn8_split_noborder(void);
void test_nield_distance_transform_conn8_split_border(void);
void test_nield_distance_transform_octagonal48_split_noborder(void);
void test_nield_distance_transform_octagonal48_split_border(void);
void test_nield_distance_transform_octagonal84_split_noborder(void);
void test_nield_distance_transform_octagonal84_split_border(void);
void test_nield_distance_transform_octagonal_split_noborder(void);
void test_nield_distance_transform_octagonal_split_border(void);
void test_nield_distance_transform_euclidean_split_noborder(void);
void test_nield_distance_transform_euclidean_split_border(void);
void test_nield_resample_down(void);
void test_nield_resample_up(void);
void test_nield_extend_border(void);
void test_nield_extend_mirror(void);
void test_nield_extend_periodic(void);
void test_nield_extend_fixed(void);
void test_nield_extend_undefined(void);
void test_nield_grain_sizes(void);
void test_nield_grain_bounding_boxes(void);
void test_nield_grain_bounding_boxes_periodic(void);
void test_nield_grain_inscribed_boxes(void);
void test_nield_grain_fill_voids_simple(void);
void test_nield_grain_fill_voids_nonsimple(void);
void test_nield_grain_fill_voids_unchanged(void);
void test_nield_clear_touching_border_touching(void);
void test_nield_clear_touching_border_completely(void);
void test_nield_autocrop_normal(void);
void test_nield_autocrop_empty(void);
void test_nield_filter_minmax_minimum(void);
void test_nield_filter_minmax_maximum(void);
void test_nield_filter_minmax_range(void);
void test_nield_filter_minmax_dilation(void);
void test_nield_filter_minmax_frosion(void);
void test_nield_boundary_pixels_border(void);
void test_nield_boundary_pixels_noborder(void);
void test_nield_convex_hull_tightness(void);
void test_nield_convex_hull_convexity(void);
void test_nield_convex_hull_coverage(void);
void test_nield_mark_range_inclusive(void);
void test_nield_mark_range_exclusive(void);
void test_nield_mark_by_threshold_above(void);
void test_nield_mark_by_threshold_below(void);
void test_nield_merge_clear(void);
void test_nield_merge_fill(void);
void test_nield_merge_min(void);
void test_nield_merge_max(void);
void test_nield_merge_keep(void);
void test_nield_merge_copy(void);
void test_nield_merge_subtract(void);
void test_nield_merge_revsubtract(void);
void test_nield_merge_xor(void);
void test_nield_merge_equal(void);
void test_nield_merge_outside(void);
void test_nield_merge_not(void);
void test_nield_merge_ncopy(void);
void test_nield_merge_nor(void);
void test_nield_merge_nand(void);
void test_nield_merge_implies(void);
void test_nield_merge_converse(void);
void test_nield_grain_quantity_pixel_area(void);
void test_nield_grain_quantity_projected_area(void);
void test_nield_grain_quantity_equiv_disc_radius(void);
void test_nield_grain_quantity_maximum(void);
void test_nield_grain_quantity_minimum(void);
void test_nield_grain_quantity_mean(void);
void test_nield_grain_quantity_rms(void);
void test_nield_grain_quantity_median(void);
void test_nield_grain_quantity_surface_area(void);
void test_nield_grain_quantity_center_x(void);
void test_nield_grain_quantity_center_y(void);
void test_nield_grain_quantity_slope_theta(void);
void test_nield_grain_quantity_slope_phi(void);
void test_nield_grain_quantity_volume_0(void);
void test_nield_grain_quantity_volume_min(void);
void test_nield_grain_quantity_volume_laplace(void);
void test_nield_grain_quantity_half_height_area(void);
void test_nield_grain_quantity_boundary_minimum(void);
void test_nield_grain_quantity_boundary_maximum(void);
void test_nield_grain_quantity_maximum_project_size(void);
void test_nield_grain_quantity_maximum_project_angle(void);
void test_nield_grain_quantity_minimum_project_size(void);
void test_nield_grain_quantity_minimum_project_angle(void);
void test_nield_grain_quantity_equiv_ellipse(void);
void test_nield_grain_quantity_boundary_length(void);
void test_nield_grain_quantity_convex_hull_area(void);
void test_nield_grain_quantity_circumcircle_r(void);
void test_nield_grain_quantity_circumcircle_x(void);
void test_nield_grain_quantity_circumcircle_y(void);
void test_shaped_elliptic_nield_fill_tall1(void);
void test_shaped_elliptic_nield_fill_flat1(void);
void test_shaped_elliptic_nield_fill_tall2(void);
void test_shaped_elliptic_nield_fill_flat2(void);
void test_shaped_elliptic_field_fill_tall1(void);
void test_shaped_elliptic_field_fill_flat1(void);
void test_shaped_elliptic_field_fill_tall2(void);
void test_shaped_elliptic_field_fill_flat2(void);
void test_shaped_elliptic_nield_fill_small(void);
void test_shaped_elliptic_field_fill_small(void);
void test_shaped_elliptic_nield_fill_xysym(void);
void test_shaped_elliptic_field_fill_xysym(void);
void test_shaped_elliptic_nield_fill_intersect(void);
void test_shaped_elliptic_field_fill_intersect(void);
void test_shaped_elliptic_nield_extract_data(void);
void test_shaped_elliptic_nield_extract_coords(void);
void test_shaped_elliptic_field_extract_data(void);
void test_shaped_elliptic_field_extract_coords(void);
void test_shaped_circular_nield_fill_small(void);
void test_shaped_circular_field_fill_small(void);
void test_shaped_circular_nield_fill_intersect(void);
void test_shaped_circular_field_fill_intersect(void);
void test_shaped_circular_nield_extract_data(void);
void test_shaped_circular_nield_extract_coords(void);
void test_shaped_circular_field_extract_data(void);
void test_shaped_circular_field_extract_coords(void);
void test_shaped_linear8_nield_fill_small(void);
void test_shaped_linear8_nield_fill_connected(void);
void test_shaped_linear8_nield_fill_xysym(void);
void test_shaped_linear8_nield_fill_signsym(void);
void test_shaped_linear8_nield_fill_intersect(void);
void test_shaped_linear8_nield_extract_data(void);
void test_shaped_linear8_nield_extract_coords(void);
void test_shaped_linear4_nield_fill_small(void);
void test_shaped_linear4_nield_fill_connected(void);
void test_shaped_linear4_nield_fill_superset(void);
void test_shaped_linear4_nield_fill_xysym(void);
void test_shaped_linear4_nield_fill_signsym(void);
void test_shaped_linear4_nield_fill_intersect(void);
void test_shaped_linear4_nield_extract_data(void);
void test_shaped_linear4_nield_extract_coords(void);
void test_brick_basic(void);
void test_brick_data_changed(void);
void test_brick_serialization(void);
void test_brick_copy(void);
void test_brick_assign(void);
void test_brick_compatibility_res(void);
void test_brick_compatibility_real(void);
void test_brick_compatibility_lateral(void);
void test_brick_compatibility_value(void);
void test_brick_compatibility_measure(void);
void test_brick_compatibility_axiscal(void);
void test_brick_compatibility_mixed(void);
void test_surface_basic(void);
void test_surface_data_changed(void);
void test_surface_serialization(void);
void test_surface_copy(void);
void test_surface_assign(void);
void test_spectra_basic(void);
void test_spectra_curves(void);
void test_spectra_serialization(void);
void test_spectra_copy(void);
void test_spectra_assign(void);
void test_lawn_basic(void);
void test_lawn_curve_data(void);
void test_lawn_serialization(void);
void test_lawn_copy(void);
void test_lawn_assign(void);
void test_selection_axis_basic(void);
void test_selection_axis_serialization(void);
void test_selection_axis_copy(void);
void test_selection_axis_assign(void);
void test_selection_ellipse_basic(void);
void test_selection_ellipse_serialization(void);
void test_selection_ellipse_copy(void);
void test_selection_ellipse_assign(void);
void test_selection_lattice_basic(void);
void test_selection_lattice_serialization(void);
void test_selection_lattice_copy(void);
void test_selection_lattice_assign(void);
void test_selection_line_basic(void);
void test_selection_line_serialization(void);
void test_selection_line_copy(void);
void test_selection_line_assign(void);
void test_selection_path_basic(void);
void test_selection_path_serialization(void);
void test_selection_path_copy(void);
void test_selection_path_assign(void);
void test_selection_point_basic(void);
void test_selection_point_serialization(void);
void test_selection_point_copy(void);
void test_selection_point_assign(void);
void test_selection_quad_basic(void);
void test_selection_quad_serialization(void);
void test_selection_quad_copy(void);
void test_selection_quad_assign(void);
void test_selection_rectangle_basic(void);
void test_selection_rectangle_serialization(void);
void test_selection_rectangle_copy(void);
void test_selection_rectangle_assign(void);
void test_selection_get_changed_object(void);
void test_curve_model_basic(void);
void test_curve_model_data(void);
void test_curve_model_serialization(void);
void test_curve_model_copy(void);
void test_curve_model_assign(void);
void test_graph_model_basic(void);
void test_graph_model_serialization(void);
void test_graph_model_copy(void);
void test_graph_model_assign(void);
void test_module_utils_get_gboolean8(void);
void test_module_utils_get_guint16_be(void);
void test_module_utils_get_guint16_le(void);
void test_module_utils_get_gint16_be(void);
void test_module_utils_get_gint16_le(void);
void test_module_utils_get_guint32_be(void);
void test_module_utils_get_guint32_le(void);
void test_module_utils_get_gint32_be(void);
void test_module_utils_get_gint32_le(void);
void test_module_utils_get_guint64_be(void);
void test_module_utils_get_guint64_le(void);
void test_module_utils_get_gint64_be(void);
void test_module_utils_get_gint64_le(void);
void test_module_utils_get_gfloat_be(void);
void test_module_utils_get_gfloat_le(void);
void test_module_utils_get_gdouble_be(void);
void test_module_utils_get_gdouble_le(void);
void test_module_utils_get_pascal_real_be(void);
void test_module_utils_get_pascal_real_le(void);
void test_module_utils_nonsquare_image(void);
void test_module_utils_image_remove_bad_bad(void);
void test_module_utils_image_remove_bad_nobad(void);
void test_module_utils_mask_nans(void);
void test_file_in_construction(void);
void test_file_ids(void);
void test_file_parse_key(void);
void test_file_serialization(void);
void test_file_copy(void);
void test_file_assign(void);
void test_file_set_link(void);
void test_file_set_title_image(void);
void test_file_set_title_graph(void);
void test_file_set_title_volume(void);
void test_file_set_title_xyz(void);
void test_file_set_title_cmap(void);
void test_file_key_image(void);
void test_file_key_graph(void);
void test_file_key_volume(void);
void test_file_key_xyz(void);
void test_file_key_cmap(void);
void test_file_sync_items_image_nodelete(void);
void test_file_sync_items_image_delete(void);
void test_file_copy_data_image(void);
void test_file_remove_image(void);
